# TRTC SDK

English | [简体中文](./README-zh_CN.md)

## Overview

Leveraging Tencent's many years of experience in network and audio/video technologies, Tencent Real-Time Communication (TRTC) offers solutions for group audio/video calls and low-latency interactive live streaming. With TRTC, you can quickly develop cost-effective, low-latency, and high-quality interactive audio/video services. [Learn more](https://trtc.io/document)...

> We offer SDKs for web, Android, iOS, Windows, Flutter, WeChat Mini Program, and [other mainstream platforms](https://github.com/LiteAVSDK?q=TRTC_&type=all&sort=).

## Changelog

For the changelog of the SDK, see [Release Notes (Web)](https://trtc.io/document/53626).

## Contents

```
.
├── README.md
├── v5                     -- The latest version of the TRTC web SDK 5.x
├── SDK                     -- The latest version of the TRTC web SDK 4.x
├── base-js                 -- The TRTC web basic demo
├── base-react-next         -- TRTC web API examples
├── quick-demo-js           -- TRTC web quick demo (native JavaScript edition)
├── quick-demo-vue2-js      -- TRTC web quick demo (Vue.js 2 edition)
└── quick-demo-vue3-ts      -- TRTC web quick demo (Vue.js 3 edition)
```

**v5**

- You can find the latest version of the [TRTC web SDK 5.x](https://www.npmjs.com/package/trtc-sdk-v5) in the `SDK` directory.

**SDK**

- You can find the latest version of the [TRTC web SDK 4.x](https://www.npmjs.com/package/trtc-js-sdk) in the `SDK` directory.

**base-js**

- The `base-js` directory contains the TRTC web basic demo, which integrates capabilities including audio/video call and device selection. It was developed using jQuery and can be run in a browser.
- For information about how to run the demo, see [base-js](https://github.com/LiteAVSDK/TRTC_Web/tree/main/base-js).
- Click [here](https://web.sdk.qcloud.com/trtc/webrtc/demo/latest/official-demo/index.html) to try out the basic TRTC demo for web online.

**base-react-next**

- The `base-react-next` directory contains TRTC Web API Examples, which shows you how and when to use different [APIs](https://web.sdk.qcloud.com/trtc/webrtc/doc/en/Client.html) of the [TRTC web SDK](https://www.npmjs.com/package/trtc-js-sdk). Web API Examples was developed based on [Next.js](https://www.nextjs.cn/). You need to install Node.js to use it.
- For information about how to run TRTC Web API Examples, see [base-react-next](https://github.com/LiteAVSDK/TRTC_Web/tree/main/base-react-next).
- Click [here](https://web.sdk.qcloud.com/trtc/webrtc/demo/api-sample/basic-rtc.html?lang=en) to try out TRTC web API examples online.

**quick-demo-js**

- The `quick-demo-js` directory stores the native JavaScript edition of the quick TRTC demo for web, which integrates features such as basic audio/video call and device selection of the [TRTC web SDK](https://www.npmjs.com/package/trtc-js-sdk). The demo is developed with native JavaScript and can directly run in a browser.
- For information about how to run the TRTC web quick demo (JavaScript), see [quick-demo-js](https://github.com/LiteAVSDK/TRTC_Web/tree/main/quick-demo-js).
- Click [here](https://web.sdk.qcloud.com/trtc/webrtc/demo/quick-demo-js/index.html) to try out the native JavaScript edition of the quick TRTC demo for web online.

**quick-demo-vue2-js**

- The `quick-demo-vue2-js` directory contains the TRTC web quick demo (Vue.js 2.0), which integrates capabilities including audio/video call and device selection. It was developed using [Vue.js 2.0](https://v2.vuejs.org/). You need to install Node.js to use it.
- For information about how to run the TRTC web quick demo (Vue.js 2.0), see [quick-demo-vue2-js](https://github.com/LiteAVSDK/TRTC_Web/tree/main/quick-demo-vue2-js).
- Click [here](https://web.sdk.qcloud.com/trtc/webrtc/demo/quick-demo-vue2-js/index.html) to try out the Vue.js 2 edition of the quick TRTC demo for web online.

**quick-demo-vue3-ts**

- The `quick-demo-vue3-ts` directory contains the TRTC web quick demo (Vue.js 3.0), which integrates capabilities including audio/video call and device selection. It was developed using [Vue.js 3.0](https://vuejs.org/). You need to install Node.js to use it.
- For information about how to run the TRTC web quick demo (Vue.js 3.0), see [quick-demo-vue3-ts](https://github.com/LiteAVSDK/TRTC_Web/tree/main/quick-demo-vue3-ts).
- Click [here](https://web.sdk.qcloud.com/trtc/webrtc/demo/quick-demo-vue3-ts/index.html) to try out the Vue.js 3 edition of the quick TRTC demo for web online.


## Contact Us

- If you have questions, see [FAQs](https://cloud.tencent.com/document/product/647/43018).
- To learn about how the TRTC SDK can be used in different scenarios, see [Sample Code](https://intl.cloud.tencent.com/document/product/647/42963).
- For complete API documentation, see [TRTC Web SDK](https://web.sdk.qcloud.com/trtc/webrtc/doc/en/index.html).
- [Contact us](https://intl.cloud.tencent.com/contact-us) for technical support.
- To report bugs in our sample code, please create an issue.
- Communication & Feedback   
Welcome to join our Telegram Group to communicate with our professional engineers! We are more than happy to hear from you~
Click to join: [https://t.me/+EPk6TMZEZMM5OGY1](https://t.me/+EPk6TMZEZMM5OGY1)   
Or scan the QR code   
  <img src="https://qcloudimg.tencent-cloud.cn/raw/79cbfd13877704ff6e17f30de09002dd.jpg" width="300px">    
